#!/bin/sh
#
# icecast      Start and stop the Icecast streaming media server.
#
# chkconfig:   - 96 04
# description: Icecast is an Internet based broadcasting system.
#
# processname: icecast
# config: /etc/icecast/icecast.xml
# pidfile: /var/run/icecast.pid
#

# Source function library
. /etc/rc.d/init.d/functions

# Get config.
. /etc/sysconfig/network

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

RETVAL=0

# See how we were called.
start() {
	# start daemon
	echo -n $"Starting Icecast streaming server: "
	daemon /usr/sbin/icecast -b -c /etc/icecast/icecast.xml > /dev/null
	RETVAL=$?
	[ $RETVAL -eq 0 ] && echo_success
	echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/icecast
	return $RETVAL
}

stop() {
	echo -n $"Stopping Icecast streaming server: "
	killproc icecast
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && rm -f /var/run/icecast.pid /var/lock/subsys/icecast
	return $RETVAL
}

restart() {
	stop
	start
}

case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart)
	restart
	;;
  status)
	status icecast
	;;
  condrestart)
	[ -f /var/lock/subsys/icecast ] && restart || :
	;;
  *)
	echo $"Usage: $0 {start|stop|status|condrestart|restart}"
	exit 1
esac

exit $?

